KacheCommandException class final

Aggregates command failures without rendering keys or causes.

Implemented types

Constructors

KacheCommandException(Iterable<KacheFailure> failures)
Creates an exception containing an immutable copy of failures.

Properties

failures List<KacheFailure>
Failures produced by the command.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited