KacheEventTrigger enum

The command or lifecycle transition that initiated an event trace.

Inheritance
Available extensions

Values

load → const KacheEventTrigger

A resource load.

refresh → const KacheEventTrigger

An explicit resource refresh.

prefetch → const KacheEventTrigger

A client prefetch.

poll → const KacheEventTrigger

An interval refresh.

resume → const KacheEventTrigger

Foreground resume revalidation.

network → const KacheEventTrigger

A state or failure from the configured network source.

reconnect → const KacheEventTrigger

Network recovery revalidation.

clearRefetch → const KacheEventTrigger

Revalidation requested by a clear command.

set → const KacheEventTrigger

A set-data command.

update → const KacheEventTrigger

An atomic update-data command.

invalidate → const KacheEventTrigger

An invalidate command and its optional fetch.

remove → const KacheEventTrigger

A remove command.

clear → const KacheEventTrigger

A namespace or global clear command.

close → const KacheEventTrigger

A client close command.

maintenance → const KacheEventTrigger

Persistence maintenance initiated by a read.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<KacheEventTrigger>
A constant List of the values in this enum, in order of their declaration.