KachePersistenceException class final

A persistence failure with its operation, stage, cause, and stack trace.

toString is intentionally sanitized: it does not render cause and this exception does not contain cache keys or payloads.

Implemented types

Constructors

KachePersistenceException({required KachePersistenceOperation operation, required KachePersistenceStage stage, required Object cause, required StackTrace stackTrace})
Creates a persistence exception without transforming the original error.
factory

Properties

cause Object
The original failure object.
final
hashCode int
The hash code for this object.
no setterinherited
operation KachePersistenceOperation
The persistence operation that failed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace
The original stack trace associated with cause.
final
stage KachePersistenceStage
The stage within operation that failed.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited